pub struct CustomKeyMap { /* private fields */ }Expand description
Custom key mapping manager
Implementations
Sourceimpl CustomKeyMap
impl CustomKeyMap
Sourcepub fn add_key(&mut self, key: CustomKey) -> Result<(), KeyParseError>
pub fn add_key(&mut self, key: CustomKey) -> Result<(), KeyParseError>
Add a custom key to the mapping
Errors
Returns KeyParseError::DuplicateCustomKey if a key with the same name already exists
Sourcepub fn remove_key(&mut self, name: &str) -> Option<CustomKey>
pub fn remove_key(&mut self, name: &str) -> Option<CustomKey>
Remove a custom key by name
Sourcepub fn parse_by_name(&self, name: &str) -> Option<&CustomKey>
pub fn parse_by_name(&self, name: &str) -> Option<&CustomKey>
Parse a custom key by name
Sourcepub fn parse_by_code(
&self,
code: usize,
platform: Platform,
) -> Option<&CustomKey>
pub fn parse_by_code( &self, code: usize, platform: Platform, ) -> Option<&CustomKey>
Parse a custom key by code and platform
Sourcepub fn to_code(&self, key: &CustomKey, platform: Platform) -> Option<usize>
pub fn to_code(&self, key: &CustomKey, platform: Platform) -> Option<usize>
Convert a custom key to a platform-specific code
Sourcepub fn contains_key(&self, name: &str) -> bool
pub fn contains_key(&self, name: &str) -> bool
Check if a custom key with the given name exists