pub fn parse_modifier_from_str(s: &str) -> Result<Modifier, KeyParseError>Expand description
Parse a modifier from a string using standard mappings (case-sensitive)
pub fn parse_modifier_from_str(s: &str) -> Result<Modifier, KeyParseError>Parse a modifier from a string using standard mappings (case-sensitive)