pub fn is_valid_key_code(code: usize, platform: Platform) -> bool
Check if a key code is valid for the given platform
This is a basic validation that checks if the code is within a reasonable range for the platform.