pub fn normalize_key_code(code: usize, platform: Platform) -> usize
Normalize a key code by masking out any extraneous bits
Some platforms may have additional bits set in key codes that are not part of the core key code value.